/**
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

//
// This source code implements specifications defined by the Java
// Community Process. In order to remain compliant with the specification
// DO NOT add / change / or delete method signatures!
//
package javax.activation;

import java.io.IOException;

import junit.framework.TestCase;

/**
 * @version $Rev: 485127 $ $Date: 2006-12-10 04:02:32 +0100 (Sun, 10 Dec 2006) $
 */
public class CommandInfoTest extends TestCase {
    public void testAttributes() {
        CommandInfo info = new CommandInfo("test", "test.class");
        assertEquals("test", info.getCommandName());
        assertEquals("test.class", info.getCommandClass());
    }

    public void testInvalidClassName() throws IOException {
        CommandInfo info = new CommandInfo("test", "test.class");
        try {
            info.getCommandObject(null, null);
            fail("Expected ClassNotFoundException");
        } catch (ClassNotFoundException e) {
            // ok
        }
    }

    public void testCommandObject() throws IOException, ClassNotFoundException {
        CommandInfo info = new CommandInfo("test", MockCommandObject.class.getName());
        DataHandler dh = new DataHandler("Hello", "text/plain");
        Object o = info.getCommandObject(dh, MockCommandObject.class.getClassLoader());
        assertTrue(o instanceof MockCommandObject);
        MockCommandObject bean = (MockCommandObject) o;
        assertEquals("test", bean.verb);
        assertSame(dh, bean.dh);
    }

    public static class MockCommandObject implements CommandObject {
        private String verb;
        private DataHandler dh;

        public void setCommandContext(String verb, DataHandler dh) {
            this.verb = verb;
            this.dh = dh;
        }
    }
}
